@@ -8,8 +8,6 @@
 #include <QtCore/QDateTime>
 #include <QtCore/QFileInfo>
 #include <QtCore/QFileSystemWatcher>
-#include <QtCore/QPair>
-#include <QtCore/QSharedPointer>
 #include <QtCore/QTimer>
 #include <QtHelp/QHelpContentModel>
 #include <QtHelp/QHelpEngine>
@@ -18,25 +16,29 @@
 #include <QtHelp/QHelpLink>
 #include <QtHelp/QHelpSearchEngine>
 
+#include <map>
+#include <memory>
+
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::StringLiterals;
+
 namespace {
-    const QString AppFontKey(QLatin1String("appFont"));
-    const QString AppWritingSystemKey(QLatin1String("appWritingSystem"));
-    const QString BookmarksKey(QLatin1String("Bookmarks"));
-    const QString BrowserFontKey(QLatin1String("browserFont"));
-    const QString BrowserWritingSystemKey(QLatin1String("browserWritingSystem"));
-    const QString HomePageKey(QLatin1String("homepage"));
-    const QString MainWindowKey(QLatin1String("MainWindow"));
-    const QString MainWindowGeometryKey(QLatin1String("MainWindowGeometry"));
-    const QString SearchWasAttachedKey(QLatin1String("SearchWasAttached"));
-    const QString StartOptionKey(QLatin1String("StartOption"));
-    const QString UseAppFontKey(QLatin1String("useAppFont"));
-    const QString UseBrowserFontKey(QLatin1String("useBrowserFont"));
-    const QString VersionKey(QString(QLatin1String("qtVersion%1$$$%2")).
-                             arg(QLatin1String(QT_VERSION_STR)));
-    const QString ShowTabsKey(QLatin1String("showTabs"));
-    const QString TopicChooserGeometryKey(QLatin1String("TopicChooserGeometry"));
+    const QString AppFontKey("appFont"_L1);
+    const QString AppWritingSystemKey("appWritingSystem"_L1);
+    const QString BookmarksKey("Bookmarks"_L1);
+    const QString BrowserFontKey("browserFont"_L1);
+    const QString BrowserWritingSystemKey("browserWritingSystem"_L1);
+    const QString HomePageKey("homepage"_L1);
+    const QString MainWindowKey("MainWindow"_L1);
+    const QString MainWindowGeometryKey("MainWindowGeometry"_L1);
+    const QString SearchWasAttachedKey("SearchWasAttached"_L1);
+    const QString StartOptionKey("StartOption"_L1);
+    const QString UseAppFontKey("useAppFont"_L1);
+    const QString UseBrowserFontKey("useBrowserFont"_L1);
+    const QString VersionKey("qtVersion%1$$$%2"_L1.arg(QLatin1StringView(QT_VERSION_STR)));
+    const QString ShowTabsKey("showTabs"_L1);
+    const QString TopicChooserGeometryKey("TopicChooserGeometry"_L1);
 } // anonymous namespace
 
 class TimeoutForwarder : public QObject
@@ -75,12 +77,20 @@ private:
 
     QHelpEngine * const m_helpEngine;
     QFileSystemWatcher * const m_qchWatcher;
-    typedef QPair<QDateTime, QSharedPointer<TimeoutForwarder> > RecentSignal;
-    QMap<QString, RecentSignal> m_recentQchUpdates;
+    struct RecentSignal {
+        QDateTime timestamp;
+        std::unique_ptr<TimeoutForwarder> forwarder;
+    };
+    std::map<QString, RecentSignal> m_recentQchUpdates;
 };
 
 HelpEngineWrapper *HelpEngineWrapper::helpEngineWrapper = nullptr;
 
+HelpEngineWrapper &HelpEngineWrapper::instance()
+{
+    return instance({});
+}
+
 HelpEngineWrapper &HelpEngineWrapper::instance(const QString &collectionFile)
 {
     TRACE_OBJ
@@ -727,7 +737,7 @@ void HelpEngineWrapperPrivate::qchFileChanged(const QString &fileName,
      * signal more than  once.
      */
     if (ns.isEmpty()) {
-        m_recentQchUpdates.remove(fileName);
+        m_recentQchUpdates.erase(fileName);
         return;
     }
 
@@ -738,23 +748,26 @@ void HelpEngineWrapperPrivate::qchFileChanged(const QString &fileName,
      */
 
     const auto &it = m_recentQchUpdates.find(fileName);
-    const QDateTime &now = QDateTime::currentDateTime();
+    const QDateTime now = QDateTime::currentDateTimeUtc();
 
      // Case 1: This is the first recent signal for the file.
     if (it == m_recentQchUpdates.end()) {
-        QSharedPointer<TimeoutForwarder> forwarder(new TimeoutForwarder(fileName));
-        m_recentQchUpdates.insert(fileName, RecentSignal(now, forwarder));
-        QTimer::singleShot(UpdateGracePeriod, forwarder.data(),
+        auto forwarder = std::make_unique<TimeoutForwarder>(fileName);
+        QTimer::singleShot(UpdateGracePeriod, forwarder.get(),
                            &TimeoutForwarder::forward);
+        m_recentQchUpdates.emplace(fileName,
+                                   RecentSignal{std::move(now), std::move(forwarder)});
         return;
     }
 
+    auto &[key, entry] = *it;
+
     // Case 2: The last signal for this file has not expired yet.
-    if (it.value().first > now.addMSecs(-UpdateGracePeriod)) {
+    if (entry.timestamp > now.addMSecs(-UpdateGracePeriod)) {
         if (!fromTimeout)
-            it.value().first = now;
+            entry.timestamp = now;
         else
-            QTimer::singleShot(UpdateGracePeriod, it.value().second.data(),
+            QTimer::singleShot(UpdateGracePeriod, entry.forwarder.get(),
                                &TimeoutForwarder::forward);
         return;
     }
