@@ -36,11 +36,15 @@
 #include <QtCore/qpointer.h>
 #include <QtCore/qxmlstream.h>
 
+#include <algorithm>
+
 QT_BEGIN_NAMESPACE
 
-static const char RichTextDialogGroupC[] = "RichTextDialog";
-static const char GeometryKeyC[] = "Geometry";
-static const char TabKeyC[] = "Tab";
+using namespace Qt::StringLiterals;
+
+static constexpr auto RichTextDialogGroupC = "RichTextDialog"_L1;
+static constexpr auto GeometryKeyC = "Geometry"_L1;
+static constexpr auto TabKeyC = "Tab"_L1;
 
 const bool simplifyRichTextDefault = true;
 
@@ -49,7 +53,7 @@ namespace qdesigner_internal {
 // Richtext simplification filter helpers: Elements to be discarded
 static inline bool filterElement(QStringView name)
 {
-    return name != QStringLiteral("meta") && name != QStringLiteral("style");
+    return name != "meta"_L1 && name != "style"_L1;
 }
 
 // Richtext simplification filter helpers: Filter attributes of elements
@@ -61,15 +65,15 @@ static inline void filterAttributes(QStringView name,
         return;
 
      // No style attributes for <body>
-    if (name == QStringLiteral("body")) {
+    if (name == "body"_L1) {
         atts->clear();
         return;
     }
 
     // Clean out everything except 'align' for 'p'
-    if (name == QStringLiteral("p")) {
+    if (name == "p"_L1) {
         for (auto it = atts->begin(); it != atts->end(); ) {
-            if (it->name() == QStringLiteral("align")) {
+            if (it->name() == "align"_L1) {
                 ++it;
                 *paragraphAlignmentFound = true;
             } else {
@@ -83,11 +87,8 @@ static inline void filterAttributes(QStringView name,
 // Richtext simplification filter helpers: Check for blank QStringView.
 static inline bool isWhiteSpace(QStringView in)
 {
-    const int count = in.size();
-    for (int i = 0; i < count; i++)
-        if (!in.at(i).isSpace())
-            return false;
-    return true;
+    return std::all_of(in.cbegin(), in.cend(),
+                       [](QChar c) { return c.isSpace(); });
 }
 
 // Richtext simplification filter: Remove hard-coded font settings,
@@ -144,6 +145,8 @@ public:
 
     QToolBar *createToolBar(QDesignerFormEditorInterface *core, QWidget *parent = nullptr);
 
+    QString text(Qt::TextFormat format) const;
+
     bool simplifyRichText() const      { return m_simplifyRichText; }
 
 public slots:
@@ -151,7 +154,6 @@ public slots:
     void setFontPointSize(double);
     void setText(const QString &text);
     void setSimplifyRichText(bool v);
-    QString text(Qt::TextFormat format) const;
 
 signals:
     void stateChanged();
@@ -176,17 +178,15 @@ public slots:
 
 private:
     RichTextEditor *m_editor;
-    Ui::AddLinkDialog *m_ui;
+    QT_PREPEND_NAMESPACE(Ui)::AddLinkDialog *m_ui;
 };
 
 AddLinkDialog::AddLinkDialog(RichTextEditor *editor, QWidget *parent) :
     QDialog(parent),
-    m_ui(new Ui::AddLinkDialog)
+    m_ui(new QT_PREPEND_NAMESPACE(Ui)::AddLinkDialog)
 {
     m_ui->setupUi(this);
 
-    setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
-
     m_editor = editor;
 }
 
@@ -215,12 +215,7 @@ void AddLinkDialog::accept()
     const QString url = m_ui->urlInput->text();
 
     if (!title.isEmpty()) {
-        QString html = QStringLiteral("<a href=\"");
-        html += url;
-        html += QStringLiteral("\">");
-        html += title;
-        html += QStringLiteral("</a>");
-
+        const QString html = "<a href=\""_L1 + url + "\">"_L1 + title + "</a>"_L1;
         m_editor->insertHtml(html);
     }
 
@@ -265,9 +260,9 @@ void HtmlTextEdit::contextMenuEvent(QContextMenuEvent *event)
     };
 
     for (const Entry &e : entries) {
-        QAction *entityAction = new QAction(QLatin1String(e.text),
+        QAction *entityAction = new QAction(QLatin1StringView(e.text),
                                             htmlMenu);
-        entityAction->setData(QLatin1String(e.entity));
+        entityAction->setData(QLatin1StringView(e.entity));
         htmlMenu->addAction(entityAction);
     }
 
@@ -376,7 +371,6 @@ private:
 };
 
 static QAction *createCheckableAction(const QIcon &icon, const QString &text,
-                                      QObject *receiver, const char *slot,
                                       QObject *parent = nullptr)
 {
     QAction *result = new QAction(parent);
@@ -384,8 +378,6 @@ static QAction *createCheckableAction(const QIcon &icon, const QString &text,
     result->setText(text);
     result->setCheckable(true);
     result->setChecked(false);
-    if (slot)
-        QObject::connect(result, SIGNAL(triggered(bool)), receiver, slot);
     return result;
 }
 
@@ -415,20 +407,23 @@ RichTextEditorToolBar::RichTextEditorToolBar(QDesignerFormEditorInterface *core,
     // Bold, italic and underline buttons
 
     m_bold_action = createCheckableAction(
-            createIconSet(QStringLiteral("textbold.png")),
-            tr("Bold"), editor, SLOT(setFontBold(bool)), this);
+            createIconSet(QIcon::ThemeIcon::FormatTextBold,
+                          "textbold.png"_L1), tr("Bold"), this);
+    connect(m_bold_action, &QAction::triggered, editor, &RichTextEditor::setFontBold);
     m_bold_action->setShortcut(tr("CTRL+B"));
     addAction(m_bold_action);
 
     m_italic_action = createCheckableAction(
-            createIconSet(QStringLiteral("textitalic.png")),
-            tr("Italic"), editor, SLOT(setFontItalic(bool)), this);
+            createIconSet(QIcon::ThemeIcon::FormatTextItalic,
+                          "textitalic.png"_L1), tr("Italic"), this);
+    connect(m_italic_action, &QAction::triggered, editor, &RichTextEditor::setFontItalic);
     m_italic_action->setShortcut(tr("CTRL+I"));
     addAction(m_italic_action);
 
     m_underline_action = createCheckableAction(
-            createIconSet(QStringLiteral("textunder.png")),
-            tr("Underline"), editor, SLOT(setFontUnderline(bool)), this);
+            createIconSet(QIcon::ThemeIcon::FormatTextUnderline,
+                          "textunder.png"_L1), tr("Underline"), this);
+    connect(m_underline_action, &QAction::triggered, editor, &RichTextEditor::setFontUnderline);
     m_underline_action->setShortcut(tr("CTRL+U"));
     addAction(m_underline_action);
 
@@ -441,28 +436,30 @@ RichTextEditorToolBar::RichTextEditorToolBar(QDesignerFormEditorInterface *core,
             this, &RichTextEditorToolBar::alignmentActionTriggered);
 
     m_align_left_action = createCheckableAction(
-            createIconSet(QStringLiteral("textleft.png")),
-            tr("Left Align"), editor, nullptr, alignment_group);
+            createIconSet(QIcon::ThemeIcon::FormatJustifyLeft,
+                          "textleft.png"_L1), tr("Left Align"), alignment_group);
     addAction(m_align_left_action);
 
     m_align_center_action = createCheckableAction(
-            createIconSet(QStringLiteral("textcenter.png")),
-            tr("Center"), editor, nullptr, alignment_group);
+            createIconSet(QIcon::ThemeIcon::FormatJustifyCenter,
+                          "textcenter.png"_L1), tr("Center"), alignment_group);
     addAction(m_align_center_action);
 
     m_align_right_action = createCheckableAction(
-            createIconSet(QStringLiteral("textright.png")),
-            tr("Right Align"), editor, nullptr, alignment_group);
+            createIconSet(QIcon::ThemeIcon::FormatJustifyRight,
+                          "textright.png"_L1), tr("Right Align"), alignment_group);
     addAction(m_align_right_action);
 
     m_align_justify_action = createCheckableAction(
-            createIconSet(QStringLiteral("textjustify.png")),
-            tr("Justify"), editor, nullptr, alignment_group);
+            createIconSet(QIcon::ThemeIcon::FormatJustifyFill,
+                          "textjustify.png"_L1), tr("Justify"), alignment_group);
     addAction(m_align_justify_action);
 
     m_layoutDirectionAction = createCheckableAction(
-            createIconSet(QStringLiteral("righttoleft.png")),
-            tr("Right to Left"), this, SLOT(layoutDirectionChanged()));
+            createIconSet(QIcon::ThemeIcon::FormatTextDirectionRtl,
+                          "righttoleft.png"_L1), tr("Right to Left"));
+    connect(m_layoutDirectionAction, &QAction::triggered,
+            this, &RichTextEditorToolBar::layoutDirectionChanged);
     addAction(m_layoutDirectionAction);
 
     addSeparator();
@@ -470,27 +467,27 @@ RichTextEditorToolBar::RichTextEditorToolBar(QDesignerFormEditorInterface *core,
     // Superscript and subscript buttons
 
     m_valign_sup_action = createCheckableAction(
-            createIconSet(QStringLiteral("textsuperscript.png")),
-            tr("Superscript"),
-            this, SLOT(setVAlignSuper(bool)), this);
+            createIconSet("textsuperscript.png"_L1), tr("Superscript"), this);
+    connect(m_valign_sup_action, &QAction::triggered,
+            this, &RichTextEditorToolBar::setVAlignSuper);
     addAction(m_valign_sup_action);
 
     m_valign_sub_action = createCheckableAction(
-            createIconSet(QStringLiteral("textsubscript.png")),
-            tr("Subscript"),
-            this, SLOT(setVAlignSub(bool)), this);
+            createIconSet("textsubscript.png"_L1), tr("Subscript"), this);
+    connect(m_valign_sub_action, &QAction::triggered,
+            this, &RichTextEditorToolBar::setVAlignSub);
     addAction(m_valign_sub_action);
 
     addSeparator();
 
     // Insert hyperlink and image buttons
 
-    m_link_action->setIcon(createIconSet(QStringLiteral("textanchor.png")));
+    m_link_action->setIcon(createIconSet("textanchor.png"_L1));
     m_link_action->setText(tr("Insert &Link"));
     connect(m_link_action, &QAction::triggered, this, &RichTextEditorToolBar::insertLink);
     addAction(m_link_action);
 
-    m_image_action->setIcon(createIconSet(QStringLiteral("insertimage.png")));
+    m_image_action->setIcon(createIconSet("insertimage.png"_L1));
     m_image_action->setText(tr("Insert &Image"));
     connect(m_image_action, &QAction::triggered, this, &RichTextEditorToolBar::insertImage);
     addAction(m_image_action);
@@ -506,8 +503,9 @@ RichTextEditorToolBar::RichTextEditorToolBar(QDesignerFormEditorInterface *core,
 
     // Simplify rich text
     m_simplify_richtext_action
-        = createCheckableAction(createIconSet(QStringLiteral("simplifyrichtext.png")),
-                                tr("Simplify Rich Text"), m_editor, SLOT(setSimplifyRichText(bool)));
+        = createCheckableAction(createIconSet("simplifyrichtext.png"_L1), tr("Simplify Rich Text"));
+    connect(m_simplify_richtext_action, &QAction::triggered,
+            m_editor, &RichTextEditor::setSimplifyRichText);
     m_simplify_richtext_action->setChecked(m_editor->simplifyRichText());
     connect(m_editor.data(), &RichTextEditor::simplifyRichTextChanged,
             m_simplify_richtext_action, &QAction::setChecked);
@@ -736,13 +734,12 @@ RichTextEditorDialog::RichTextEditorDialog(QDesignerFormEditorInterface *core, Q
     m_initialTab(RichTextIndex)
 {
     setWindowTitle(tr("Edit text"));
-    setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
 
     // Read settings
     const QDesignerSettingsInterface *settings = core->settingsManager();
-    const QString rootKey = QLatin1String(RichTextDialogGroupC) + QLatin1Char('/');
-    const QByteArray lastGeometry = settings->value(rootKey + QLatin1String(GeometryKeyC)).toByteArray();
-    const int initialTab = settings->value(rootKey + QLatin1String(TabKeyC), QVariant(m_initialTab)).toInt();
+    const QString rootKey = RichTextDialogGroupC + u'/';
+    const QByteArray lastGeometry = settings->value(rootKey + GeometryKeyC).toByteArray();
+    const int initialTab = settings->value(rootKey + TabKeyC, QVariant(m_initialTab)).toInt();
     if (initialTab == RichTextIndex || initialTab == SourceIndex)
         m_initialTab = initialTab;
 
@@ -792,10 +789,10 @@ RichTextEditorDialog::RichTextEditorDialog(QDesignerFormEditorInterface *core, Q
 RichTextEditorDialog::~RichTextEditorDialog()
 {
     QDesignerSettingsInterface *settings = m_core->settingsManager();
-    settings->beginGroup(QLatin1String(RichTextDialogGroupC));
+    settings->beginGroup(RichTextDialogGroupC);
 
-    settings->setValue(QLatin1String(GeometryKeyC), saveGeometry());
-    settings->setValue(QLatin1String(TabKeyC), m_tab_widget->currentIndex());
+    settings->setValue(GeometryKeyC, saveGeometry());
+    settings->setValue(TabKeyC, m_tab_widget->currentIndex());
     settings->endGroup();
 }
 
