@@ -3,10 +3,11 @@
 
 #include "stylesheeteditor_p.h"
 #include "csshighlighter_p.h"
+#include "iconloader_p.h"
 #include "iconselector_p.h"
-#include "qtgradientmanager.h"
-#include "qtgradientviewdialog.h"
-#include "qtgradientutils.h"
+#include "qtgradientmanager_p.h"
+#include "qtgradientviewdialog_p.h"
+#include "qtgradientutils_p.h"
 #include "qdesigner_utils_p.h"
 
 #include <QtDesigner/abstractformwindow.h>
@@ -17,7 +18,7 @@
 #include <QtDesigner/abstractsettings.h>
 #include <QtDesigner/qextensionmanager.h>
 
-#include <texteditfindwidget.h>
+#include <texteditfindwidget_p.h>
 
 #include <QtWidgets/qcolordialog.h>
 #include <QtWidgets/qdialogbuttonbox.h>
@@ -37,30 +38,25 @@ QT_BEGIN_NAMESPACE
 
 using namespace Qt::StringLiterals;
 
-static const char styleSheetProperty[] = "styleSheet";
-static const char StyleSheetDialogC[] = "StyleSheetDialog";
-static const char seGeometry[] = "Geometry";
+static constexpr auto styleSheetProperty = "styleSheet"_L1;
+static constexpr auto StyleSheetDialogC = "StyleSheetDialog"_L1;
+static constexpr auto seGeometry = "Geometry"_L1;
 
 namespace qdesigner_internal {
 
 StyleSheetEditor::StyleSheetEditor(QWidget *parent)
     : QTextEdit(parent)
 {
-    enum : int { DarkThreshold = 200 }; // Observed 239 on KDE/Dark
-
     setTabStopDistance(fontMetrics().horizontalAdvance(u' ') * 4);
     setAcceptRichText(false);
 
-    const QColor textColor = palette().color(QPalette::WindowText);
-    const bool darkMode = textColor.red() > DarkThreshold
-        && textColor.green() > DarkThreshold
-        && textColor.blue() > DarkThreshold;
+    const bool darkMode = isDarkMode();
 
     CssHighlightColors colors;
     colors.selector = darkMode ? QColor(Qt::red).lighter() : QColor(Qt::darkRed);
     const QColor blue(Qt::blue);
     colors.property = darkMode ? blue.lighter() : blue;
-    colors.pseudo1 = colors.pseudo2 = colors.value = textColor;
+    colors.pseudo1 = colors.pseudo2 = colors.value = palette().color(QPalette::WindowText);
     colors.quote = darkMode ? Qt::magenta : Qt::darkMagenta;
     colors.comment = darkMode ? Qt::green : Qt::darkGreen;
 
@@ -170,10 +166,10 @@ StyleSheetEditorDialog::StyleSheetEditorDialog(QDesignerFormEditorInterface *cor
     m_editor->setFocus();
 
     QDesignerSettingsInterface *settings = core->settingsManager();
-    settings->beginGroup(QLatin1StringView(StyleSheetDialogC));
+    settings->beginGroup(StyleSheetDialogC);
 
-    if (settings->contains(QLatin1StringView(seGeometry)))
-        restoreGeometry(settings->value(QLatin1StringView(seGeometry)).toByteArray());
+    if (settings->contains(seGeometry))
+        restoreGeometry(settings->value(seGeometry).toByteArray());
 
     settings->endGroup();
 }
@@ -181,9 +177,9 @@ StyleSheetEditorDialog::StyleSheetEditorDialog(QDesignerFormEditorInterface *cor
 StyleSheetEditorDialog::~StyleSheetEditorDialog()
 {
     QDesignerSettingsInterface *settings = m_core->settingsManager();
-    settings->beginGroup(QLatin1StringView(StyleSheetDialogC));
+    settings->beginGroup(StyleSheetDialogC);
 
-    settings->setValue(QLatin1StringView(seGeometry), saveGeometry());
+    settings->setValue(seGeometry, saveGeometry());
     settings->endGroup();
 }
 
@@ -390,7 +386,7 @@ StyleSheetPropertyEditorDialog::StyleSheetPropertyEditorDialog(QWidget *parent,
     QDesignerPropertySheetExtension *sheet =
             qt_extension<QDesignerPropertySheetExtension*>(m_fw->core()->extensionManager(), m_widget);
     Q_ASSERT(sheet != nullptr);
-    const int index = sheet->indexOf(QLatin1StringView(styleSheetProperty));
+    const int index = sheet->indexOf(styleSheetProperty);
     const PropertySheetStringValue value = qvariant_cast<PropertySheetStringValue>(sheet->property(index));
     setText(value.value());
 }
@@ -398,7 +394,7 @@ StyleSheetPropertyEditorDialog::StyleSheetPropertyEditorDialog(QWidget *parent,
 void StyleSheetPropertyEditorDialog::applyStyleSheet()
 {
     const PropertySheetStringValue value(text(), false);
-    m_fw->cursor()->setWidgetProperty(m_widget, QLatin1StringView(styleSheetProperty), QVariant::fromValue(value));
+    m_fw->cursor()->setWidgetProperty(m_widget, styleSheetProperty, QVariant::fromValue(value));
 }
 
 } // namespace qdesigner_internal
