@@ -197,9 +197,11 @@ int Generator::appendSortedQmlNames(Text &text, const Node *base, const QStringL
 
   \sa beginSubPage()
  */
-QFile *Generator::openSubPageFile(const Node *node, const QString &fileName)
+QFile *Generator::openSubPageFile(const PageNode *node, const QString &fileName)
 {
-    if (s_outFileNames.contains(fileName))
+    // Skip generating a warning for license attribution pages, as their source
+    // is generated by qtattributionsscanner and may potentially include duplicates
+    if (s_outFileNames.contains(fileName) && !node->isAttribution())
         node->location().warning("Already generated %1 for this project"_L1.arg(fileName));
 
     QString path = outputDir() + QLatin1Char('/') + fileName;
@@ -233,7 +235,8 @@ QFile *Generator::openSubPageFile(const Node *node, const QString &fileName)
  */
 void Generator::beginSubPage(const Node *node, const QString &fileName)
 {
-    QFile *outFile = openSubPageFile(node, fileName);
+    Q_ASSERT(node->isPageNode());
+    QFile *outFile = openSubPageFile(static_cast<const PageNode*>(node), fileName);
     auto *out = new QTextStream(outFile);
     outStreamStack.push(out);
 }
@@ -792,6 +795,9 @@ void Generator::generateBody(const Node *node, CodeMarker *marker)
                             QStringLiteral("Undocumented return value "
                                            "(hint: use 'return' or 'returns' in the text"));
             }
+        } else if (node->isQmlProperty()) {
+            if (auto *qpn = static_cast<const QmlPropertyNode *>(node); !qpn->validateDataType())
+                qpn->doc().location().warning("Invalid QML property type: %1"_L1.arg(qpn->dataType()));
         }
     }
     generateEnumValuesForQmlProperty(node, marker);
