@@ -1,46 +1,11 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the tools applications of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
-#include "qtgradientstopswidget.h"
-#include "qtgradientstopsmodel.h"
+#include "qtgradientstopswidget_p.h"
+#include "qtgradientstopsmodel_p.h"
 
 #include <QtCore/QMap>
+#include <QtCore/QHash>
 #include <QtCore/QMimeData>
 #include <QtGui/QImage>
 #include <QtGui/QPainter>
@@ -57,16 +22,13 @@ class QtGradientStopsWidgetPrivate : public QObject
     QtGradientStopsWidget *q_ptr;
     Q_DECLARE_PUBLIC(QtGradientStopsWidget)
 public:
-    typedef QMap<qreal, QColor> PositionColorMap;
-    typedef QMap<QtGradientStop *, qreal> StopPositionMap;
-
     void setGradientStopsModel(QtGradientStopsModel *model);
 
     void slotStopAdded(QtGradientStop *stop);
     void slotStopRemoved(QtGradientStop *stop);
     void slotStopMoved(QtGradientStop *stop, qreal newPos);
     void slotStopsSwapped(QtGradientStop *stop1, QtGradientStop *stop2);
-    void slotStopChanged(QtGradientStop *stop, const QColor &newColor);
+    void slotStopChanged(QtGradientStop *stop, QColor newColor);
     void slotStopSelected(QtGradientStop *stop, bool selected);
     void slotCurrentStopChanged(QtGradientStop *stop);
     void slotNewStop();
@@ -79,12 +41,12 @@ public:
 
     double fromViewport(int x) const;
     double toViewport(double x) const;
-    QtGradientStop *stopAt(const QPoint &viewportPos) const;
-    QList<QtGradientStop *> stopsAt(const QPoint &viewportPos) const;
+    QtGradientStop *stopAt(QPoint viewportPos) const;
+    QList<QtGradientStop *> stopsAt(QPoint viewportPos) const;
     void setupMove(QtGradientStop *stop, int x);
     void ensureVisible(double x); // x = stop position
     void ensureVisible(QtGradientStop *stop);
-    QtGradientStop *newStop(const QPoint &viewportPos);
+    QtGradientStop *newStop(QPoint viewportPos);
 
     bool m_backgroundCheckered;
     QtGradientStopsModel *m_model;
@@ -112,9 +74,9 @@ public:
 
     bool m_moving;
     int m_moveOffset;
-    StopPositionMap m_moveStops;
+    QHash<QtGradientStop *, qreal> m_moveStops;
 
-    PositionColorMap m_moveOriginal;
+    QMap<qreal, QColor> m_moveOriginal;
 };
 
 void QtGradientStopsWidgetPrivate::setGradientStopsModel(QtGradientStopsModel *model)
@@ -159,7 +121,7 @@ void QtGradientStopsWidgetPrivate::setGradientStopsModel(QtGradientStopsModel *m
         connect(m_model, &QtGradientStopsModel::currentStopChanged,
                     this, &QtGradientStopsWidgetPrivate::slotCurrentStopChanged);
 
-        const QtGradientStopsModel::PositionStopMap stopsMap = m_model->stops();
+        const auto stopsMap = m_model->stops();
         for (auto it = stopsMap.cbegin(), end = stopsMap.cend(); it != end; ++it)
             slotStopAdded(it.value());
 
@@ -189,7 +151,7 @@ double QtGradientStopsWidgetPrivate::toViewport(double x) const
     return w * (x * (m_scaleFactor + max) - val) / m_scaleFactor;
 }
 
-QtGradientStop *QtGradientStopsWidgetPrivate::stopAt(const QPoint &viewportPos) const
+QtGradientStop *QtGradientStopsWidgetPrivate::stopAt(QPoint viewportPos) const
 {
     double posY = m_handleSize / 2;
     for (QtGradientStop *stop : m_stops) {
@@ -204,7 +166,7 @@ QtGradientStop *QtGradientStopsWidgetPrivate::stopAt(const QPoint &viewportPos)
     return 0;
 }
 
-QList<QtGradientStop *> QtGradientStopsWidgetPrivate::stopsAt(const QPoint &viewportPos) const
+QList<QtGradientStop *> QtGradientStopsWidgetPrivate::stopsAt(QPoint viewportPos) const
 {
     QList<QtGradientStop *> stops;
     double posY = m_handleSize / 2;
@@ -262,7 +224,7 @@ void QtGradientStopsWidgetPrivate::ensureVisible(QtGradientStop *stop)
     ensureVisible(stop->position());
 }
 
-QtGradientStop *QtGradientStopsWidgetPrivate::newStop(const QPoint &viewportPos)
+QtGradientStop *QtGradientStopsWidgetPrivate::newStop(QPoint viewportPos)
 {
     QtGradientStop *copyStop = stopAt(viewportPos);
     double posX = fromViewport(viewportPos.x());
@@ -306,7 +268,7 @@ void QtGradientStopsWidgetPrivate::slotStopsSwapped(QtGradientStop *stop1, QtGra
     q_ptr->viewport()->update();
 }
 
-void QtGradientStopsWidgetPrivate::slotStopChanged(QtGradientStop *stop, const QColor &newColor)
+void QtGradientStopsWidgetPrivate::slotStopChanged(QtGradientStop *stop, QColor newColor)
 {
     Q_UNUSED(stop);
     Q_UNUSED(newColor);
@@ -468,7 +430,6 @@ void QtGradientStopsWidget::setGradientStopsModel(QtGradientStopsModel *model)
 
 void QtGradientStopsWidget::mousePressEvent(QMouseEvent *e)
 {
-    typedef QtGradientStopsModel::PositionStopMap PositionStopMap;
     if (!d_ptr->m_model)
         return;
 
@@ -487,8 +448,8 @@ void QtGradientStopsWidget::mousePressEvent(QMouseEvent *e)
         } else if (e->modifiers() & Qt::ShiftModifier) {
             QtGradientStop *oldCurrent = d_ptr->m_model->currentStop();
             if (oldCurrent) {
-                PositionStopMap stops = d_ptr->m_model->stops();
-                PositionStopMap::ConstIterator itSt = stops.constFind(oldCurrent->position());
+                const auto stops = d_ptr->m_model->stops();
+                auto itSt = stops.constFind(oldCurrent->position());
                 if (itSt != stops.constEnd()) {
                     while (itSt != stops.constFind(stop->position())) {
                         d_ptr->m_model->selectStop(itSt.value(), true);
@@ -531,9 +492,6 @@ void QtGradientStopsWidget::mouseReleaseEvent(QMouseEvent *e)
 
 void QtGradientStopsWidget::mouseMoveEvent(QMouseEvent *e)
 {
-    typedef QtGradientStopsWidgetPrivate::PositionColorMap PositionColorMap;
-    typedef QtGradientStopsModel::PositionStopMap PositionStopMap;
-    typedef QtGradientStopsWidgetPrivate::StopPositionMap StopPositionMap;
     if (!d_ptr->m_model)
         return;
 
@@ -547,7 +505,7 @@ void QtGradientStopsWidget::mouseMoveEvent(QMouseEvent *e)
         double maxOffset = 0.0;
         double minOffset = 0.0;
         bool first = true;
-        StopPositionMap::ConstIterator itStop = d_ptr->m_moveStops.constBegin();
+        auto itStop = d_ptr->m_moveStops.cbegin();
         while (itStop != d_ptr->m_moveStops.constEnd()) {
             double offset = itStop.value();
 
@@ -567,7 +525,7 @@ void QtGradientStopsWidget::mouseMoveEvent(QMouseEvent *e)
         double viewportMin = d_ptr->toViewport(-minOffset);
         double viewportMax = d_ptr->toViewport(1.0 - maxOffset);
 
-        PositionStopMap newPositions;
+        QtGradientStopsModel::PositionStopMap newPositions;
 
         int viewportX = e->position().toPoint().x() - d_ptr->m_moveOffset;
 
@@ -593,7 +551,7 @@ void QtGradientStopsWidget::mouseMoveEvent(QMouseEvent *e)
         }
 
         bool forward = true;
-        PositionStopMap::ConstIterator itNewPos = newPositions.constBegin();
+        auto itNewPos = newPositions.cbegin();
         if (itNewPos.value()->position() < itNewPos.key())
             forward = false;
 
@@ -617,7 +575,7 @@ void QtGradientStopsWidget::mouseMoveEvent(QMouseEvent *e)
                 ++itNewPos;
         }
 
-        PositionColorMap::ConstIterator itOld = d_ptr->m_moveOriginal.constBegin();
+        auto itOld = d_ptr->m_moveOriginal.cbegin();
         while (itOld != d_ptr->m_moveOriginal.constEnd()) {
             double position = itOld.key();
             if (!d_ptr->m_model->at(position))
@@ -666,7 +624,7 @@ void QtGradientStopsWidget::mouseMoveEvent(QMouseEvent *e)
         double x1 = d_ptr->fromViewport(xv1);
         double x2 = d_ptr->fromViewport(xv2);
 
-        for (QtGradientStop *stop : qAsConst(d_ptr->m_stops)) {
+        for (QtGradientStop *stop : std::as_const(d_ptr->m_stops)) {
             if ((stop->position() >= x1 && stop->position() <= x2) ||
                         beginList.contains(stop) || endList.contains(stop))
                 d_ptr->m_model->selectStop(stop, true);
@@ -707,7 +665,6 @@ void QtGradientStopsWidget::mouseDoubleClickEvent(QMouseEvent *e)
 
 void QtGradientStopsWidget::keyPressEvent(QKeyEvent *e)
 {
-    typedef QtGradientStopsModel::PositionStopMap PositionStopMap;
     if (!d_ptr->m_model)
         return;
 
@@ -715,10 +672,10 @@ void QtGradientStopsWidget::keyPressEvent(QKeyEvent *e)
         d_ptr->m_model->deleteStops();
     } else if (e->key() == Qt::Key_Left || e->key() == Qt::Key_Right ||
                 e->key() == Qt::Key_Home || e->key() == Qt::Key_End) {
-        PositionStopMap stops = d_ptr->m_model->stops();
+        const auto stops = d_ptr->m_model->stops();
         if (stops.isEmpty())
             return;
-        QtGradientStop *newCurrent = 0;
+        QtGradientStop *newCurrent = nullptr;
         QtGradientStop *current = d_ptr->m_model->currentStop();
         if (!current || e->key() == Qt::Key_Home || e->key() == Qt::Key_End) {
             if (e->key() == Qt::Key_Left || e->key() == Qt::Key_Home)
@@ -726,7 +683,7 @@ void QtGradientStopsWidget::keyPressEvent(QKeyEvent *e)
             else if (e->key() == Qt::Key_Right || e->key() == Qt::Key_End)
                 newCurrent = (--stops.constEnd()).value();
         } else {
-            PositionStopMap::ConstIterator itStop = stops.constBegin();
+            auto itStop = stops.cbegin();
             while (itStop.value() != current)
                 ++itStop;
             if (e->key() == Qt::Key_Left && itStop != stops.constBegin())
